==> mule-soap-engine-1.3.4-sources.jar: org/mule/soap/api/security/SecurityStrategy.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.api.security;


import org.mule.soap.internal.security.callback.WSPasswordCallbackHandler;

import java.util.Map;
import java.util.Optional;

/**
 * Base contract for objects that adds a level of security to the SOAP Protocol by preparing a set of CXF properties.
 * <p>
 * All securities have an Action Name and a Type (Whether should be applied to the SOAP request or SOAP response), and returns
 * a set of properties that needs to be set in the client to make it work.
 *
 * @since 1.0
 */
public interface SecurityStrategy {

  /**
   * Returns the security action name that is going to be executed in the request phase (OUT interceptors).
   *
   * @return the request action name of {@code this} security strategy.
   */
  String securityAction();

  /**
   * Returns the type of the security strategy, if applies for the request or the response.
   *
   * @return whether is the security strategy applies for the request or the response.
   */
  SecurityStrategyType securityType();

  /**
   * Returns a set of properties to be set on the SOAP request interceptors (OUT interceptors) in order to
   * applies {@code this} security strategy.
   *
   * @return a {@link Map} with the properties required to apply the security strategy.
   */
  Map<String, Object> buildSecurityProperties();

  /**
   * Gives the option to return a custom {@link WSPasswordCallbackHandler} instance allowing to compose many password handlers
   * from different security strategies.
   *
   * @return an optional {@link WSPasswordCallbackHandler} to be added to the composite callback handler.
   */
  Optional<WSPasswordCallbackHandler> buildPasswordCallbackHandler();

  /**
   * Different types of {@link SecurityStrategy} that specify when a strategy should be applied to a message.
   *
   * @since 1.0
   */
  enum SecurityStrategyType {

    /**
     * For configurations that should be applied to incoming (response) messages.
     * This configuration type is used for decrypting and verifying the signature of incoming messages.
     */
    INCOMING,

    /**
     * For configurations that should be applied to outgoing (request) messages.
     * This configuration type is used for encryption, signing and adding SAML, timestamp and username headers.
     */
    OUTGOING,

    /**
     * If the properties should be applied for both incoming and outgoing intereptors.
     */
    ALWAYS
  }
}

==> mule-soap-engine-1.6.3-sources.jar: org/mule/soap/api/security/SecurityStrategy.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.api.security;


import org.mule.soap.internal.security.callback.WSPasswordCallbackHandler;

import java.util.Map;
import java.util.Optional;

/**
 * Base contract for objects that adds a level of security to the SOAP Protocol by preparing a set of CXF properties.
 * <p>
 * All securities have an Action Name and a Type (Whether should be applied to the SOAP request or SOAP response), and returns a
 * set of properties that needs to be set in the client to make it work.
 *
 * @since 1.0
 */
public interface SecurityStrategy {

  /**
   * Returns the security action name that is going to be executed in the request phase (OUT interceptors).
   *
   * @return the request action name of {@code this} security strategy.
   */
  String securityAction();

  /**
   * Returns the type of the security strategy, if applies for the request or the response.
   *
   * @return whether is the security strategy applies for the request or the response.
   */
  SecurityStrategyType securityType();

  /**
   * Returns a set of properties to be set on the SOAP request interceptors (OUT interceptors) in order to applies {@code this}
   * security strategy.
   *
   * @return a {@link Map} with the properties required to apply the security strategy.
   */
  Map<String, Object> buildSecurityProperties();

  /**
   * Gives the option to return a custom {@link WSPasswordCallbackHandler} instance allowing to compose many password handlers
   * from different security strategies.
   *
   * @return an optional {@link WSPasswordCallbackHandler} to be added to the composite callback handler.
   */
  Optional<WSPasswordCallbackHandler> buildPasswordCallbackHandler();

  /**
   * Different types of {@link SecurityStrategy} that specify when a strategy should be applied to a message.
   *
   * @since 1.0
   */
  enum SecurityStrategyType {

    /**
     * For configurations that should be applied to incoming (response) messages. This configuration type is used for decrypting
     * and verifying the signature of incoming messages.
     */
    INCOMING,

    /**
     * For configurations that should be applied to outgoing (request) messages. This configuration type is used for encryption,
     * signing and adding SAML, timestamp and username headers.
     */
    OUTGOING,

    /**
     * If the properties should be applied for both incoming and outgoing intereptors.
     */
    ALWAYS
  }
}
